Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(451)

Unified Diff: ios/web_view/internal/cwv_browser_state.h

Issue 2710683007: Rename CRIWVBrowserState to CWVBrowserState. (Closed)
Patch Set: Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ios/web_view/internal/criwv_web_main_parts.mm ('k') | ios/web_view/internal/cwv_browser_state.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ios/web_view/internal/cwv_browser_state.h
diff --git a/ios/web_view/internal/criwv_browser_state.h b/ios/web_view/internal/cwv_browser_state.h
similarity index 74%
rename from ios/web_view/internal/criwv_browser_state.h
rename to ios/web_view/internal/cwv_browser_state.h
index cb2e4f83139987a8009643e826f901db20471443..fc6251ab1c1b36ac8c1d6666042058f5410e4b88 100644
--- a/ios/web_view/internal/criwv_browser_state.h
+++ b/ios/web_view/internal/cwv_browser_state.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef IOS_WEB_VIEW_INTERNAL_CRIWV_BROWSER_STATE_H_
-#define IOS_WEB_VIEW_INTERNAL_CRIWV_BROWSER_STATE_H_
+#ifndef IOS_WEB_VIEW_INTERNAL_CWV_BROWSER_STATE_H_
+#define IOS_WEB_VIEW_INTERNAL_CWV_BROWSER_STATE_H_
#include <memory>
@@ -22,10 +22,10 @@ namespace ios_web_view {
class CRIWVURLRequestContextGetter;
// CWV implementation of BrowserState. Can only be called from the UI thread.
-class CRIWVBrowserState : public web::BrowserState {
+class CWVBrowserState : public web::BrowserState {
public:
- explicit CRIWVBrowserState(bool off_the_record);
- ~CRIWVBrowserState() override;
+ explicit CWVBrowserState(bool off_the_record);
+ ~CWVBrowserState() override;
// web::BrowserState implementation.
bool IsOffTheRecord() const override;
@@ -35,8 +35,8 @@ class CRIWVBrowserState : public web::BrowserState {
// Returns the associated PrefService.
PrefService* GetPrefs();
- // Converts from web::BrowserState to CRIWVBrowserState.
- static CRIWVBrowserState* FromBrowserState(web::BrowserState* browser_state);
+ // Converts from web::BrowserState to CWVBrowserState.
+ static CWVBrowserState* FromBrowserState(web::BrowserState* browser_state);
private:
// Registers the preferences for this BrowserState.
@@ -54,9 +54,9 @@ class CRIWVBrowserState : public web::BrowserState {
// The PrefService associated with this BrowserState.
std::unique_ptr<PrefService> prefs_;
- DISALLOW_COPY_AND_ASSIGN(CRIWVBrowserState);
+ DISALLOW_COPY_AND_ASSIGN(CWVBrowserState);
};
} // namespace ios_web_view
-#endif // IOS_WEB_VIEW_INTERNAL_CRIWV_BROWSER_STATE_H_
+#endif // IOS_WEB_VIEW_INTERNAL_CWV_BROWSER_STATE_H_
« no previous file with comments | « ios/web_view/internal/criwv_web_main_parts.mm ('k') | ios/web_view/internal/cwv_browser_state.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698